==> smithed_libraries-0.10.0.tar.gz: smithed_libraries-0.10.0/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['smithed_libraries',
 'smithed_libraries.plugins',
 'smithed_libraries.plugins.versioning']

package_data = \
{'': ['*'],
 'smithed_libraries': ['packs/actionbar/*',
                       'packs/actionbar/data/smithed.actionbar/advancements/impl/vanilla/bed/*',
                       'packs/actionbar/data/smithed.actionbar/advancements/impl/vanilla/container/*',
                       'packs/actionbar/data/smithed.actionbar/functions/impl/*',
                       'packs/actionbar/data/smithed.actionbar/functions/impl/technical/*',
                       'packs/actionbar/data/smithed.actionbar/functions/impl/vanilla/bed/*',
                       'packs/actionbar/data/smithed.actionbar/functions/impl/vanilla/container/*',
                       'packs/actionbar/data/smithed.actionbar/functions/impl/vanilla/container/check_double_chest_lock/*',
                       'packs/actionbar/data/smithed.actionbar/predicates/impl/*',
                       'packs/actionbar/data/smithed.actionbar/tags/blocks/impl/*',
                       'packs/actionbar/data/smithed.actionbar/tags/functions/event/player/*',
                       'packs/crafter-addon/*',
                       'packs/crafter-addon/data/smithed.crafter/tags/functions/event/*',
                       'packs/crafter-addon/data/smithed.crafter_addon/functions/impl/recipes/shaped/*',
                       'packs/crafter-addon/data/smithed.crafter_addon/functions/impl/recipes/shapeless/*',
                       'packs/crafter-addon/data/smithed.crafter_addon/functions/impl/tags/*',
                       'packs/crafter-addon/data/smithed.crafter_addon/predicates/recipes/*',
                       'packs/crafter/*',
                       'packs/crafter/assets/minecraft/models/item/*',
                       'packs/crafter/assets/smithed.crafter/font/*',
                       'packs/crafter/assets/smithed.crafter/lang/*',
                       'packs/crafter/assets/smithed.crafter/models/block/*',
                       'packs/crafter/assets/smithed.crafter/textures/block/*',
                       'packs/crafter/assets/smithed.crafter/textures/gui/*',
                       'packs/crafter/data/smithed.crafter/advancements/technical/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/break/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/crafting/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/crafting/input/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/crafting/manage_invalids/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/crafting/output/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/crafting/output/clear_input/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/crafting/output/clear_input/advanced/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/crafting/output/clear_input/delete_tool/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/crafting/output/cursor_check/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/crafting/output/shift_click/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/crafting/shapeless_recipes/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/crafting/shapeless_recipes/checks/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/interact/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/entity/player/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/recipes/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/technical/*',
                       'packs/crafter/data/smithed.crafter/functions/zint/technical/*',
                       'packs/crafter/data/smithed.crafter/item_modifiers/impl/*',
                       'packs/crafter/data/smithed.crafter/loot_tables/blocks/*',
                       'packs/crafter/data/smithed.crafter/predicates/block/table/*',
                       'packs/crafter/data/smithed.crafter/predicates/block/table/special_clear/*',
                       'packs/crafter/data/smithed.crafter/predicates/block/table/tags/*',
                       'packs/crafter/data/smithed.crafter/recipes/*',
                       'packs/crafter/data/smithed.crafter/tags/functions/event/*',
                       'packs/crafter/data/smithed.custom_block/tags/functions/event/*',
                       'packs/custom-block/*',
                       'packs/custom-block/data/smithed.custom_block/advancements/impl/technical/*',
                       'packs/custom-block/data/smithed.custom_block/functions/impl/*',
                       'packs/custom-block/data/smithed.custom_block/functions/impl/place/*',
                       'packs/custom-block/data/smithed.custom_block/functions/impl/technical/*',
                       'packs/custom-block/data/smithed.custom_block/tags/blocks/*',
                       'packs/damage/*',
                       'packs/damage/data/smithed.damage/advancements/impl/player/*',
                       'packs/damage/data/smithed.damage/functions/impl/entity/*',
                       'packs/damage/data/smithed.damage/functions/impl/entity/apply/*',
                       'packs/damage/data/smithed.damage/functions/impl/entity/armor/*',
                       'packs/damage/data/smithed.damage/functions/impl/entity/attributes/*',
                       'packs/damage/data/smithed.damage/functions/impl/entity/health/*',
                       'packs/damage/data/smithed.damage/functions/impl/player/*',
                       'packs/damage/data/smithed.damage/functions/impl/technical/*',
                       'packs/damage/data/smithed.damage/tags/entity_types/*',
                       'packs/damage/data/smithed.damage/tags/functions/event/entity/*',
                       'packs/damage/data/smithed.damage/tags/functions/event/player/*',
                       'packs/enchanter/*',
                       'packs/enchanter/assets/smithed.enchanter/font/*',
                       'packs/enchanter/assets/smithed.enchanter/lang/*',
                       'packs/enchanter/assets/smithed.enchanter/textures/gui/*',
                       'packs/enchanter/data/smithed.enchanter/advancements/impl/*',
                       'packs/enchanter/data/smithed.enchanter/functions/impl/*',
                       'packs/enchanter/data/smithed.enchanter/functions/impl/block/enchanter/*',
                       'packs/enchanter/data/smithed.enchanter/functions/impl/technical/*',
                       'packs/item/*',
                       'packs/item/data/smithed.item/advancements/impl/technical/*',
                       'packs/item/data/smithed.item/functions/impl/durability/*',
                       'packs/item/data/smithed.item/functions/impl/durability/calc_mending/*',
                       'packs/item/data/smithed.item/functions/impl/durability/damage/*',
                       'packs/item/data/smithed.item/functions/impl/durability/damage/force/*',
                       'packs/item/data/smithed.item/functions/impl/durability/process/*',
                       'packs/item/data/smithed.item/functions/impl/lore/*',
                       'packs/item/data/smithed.item/functions/impl/technical/*',
                       'packs/item/data/smithed.item/item_modifiers/*',
                       'packs/item/data/smithed.item/predicates/chance/*',
                       'packs/item/data/smithed.item/tags/functions/event/*',
                       'packs/prevent-aggression/*',
                       'packs/prevent-aggression/data/smithed.prevent_aggression/functions/impl/technical/*',
                       'packs/prevent-aggression/data/smithed.prevent_aggression/tags/entity_types/*']}

install_requires = \
['beet>=0.108.5',
 'bolt-expressions>=0.17.0,<0.18.0',
 'bolt>=0.49.0,<0.50.0',
 'mecha>=0.95.0,<0.96.0',
 'pydantic>=2.5.2,<3.0.0',
 'rich>=13.9.2,<14.0.0']

setup_kwargs = {
    'name': 'smithed-libraries',
    'version': '0.10.0',
    'description': 'All of the Smithed Libraries',
    'long_description': '# Libraries\n\n[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)\n[![Discord](https://img.shields.io/discord/511303648119226382?color=%236d82cc&label=Discord&logo=discord&logoColor=white)](https://discord.gg/gkp6UqEUph)\n\n> Collection of Libraries for the Smithed Ecosystem\n\n## Downloading\n\nYou can download it from [Stable](https://smithed.dev/libraries) | [Nightly](https://nightly.link/Smithed-MC/Libraries/workflows/nightly-build/main/packs.zip)<br/>\nor<br/>\nYou can build it from source using the [beet](https://github.com/mcbeet/beet) via the [Contributing](CONTRIBUTING.md) instructions.\n',
    'author': 'Smithed Council',
    'author_email': 'team@smithed.dev',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)

==> smithed_libraries-0.11.0.tar.gz: smithed_libraries-0.11.0/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['smithed_libraries',
 'smithed_libraries.plugins',
 'smithed_libraries.plugins.versioning']

package_data = \
{'': ['*'],
 'smithed_libraries': ['packs/actionbar/*',
                       'packs/actionbar/data/smithed.actionbar/advancements/impl/vanilla/bed/*',
                       'packs/actionbar/data/smithed.actionbar/advancements/impl/vanilla/container/*',
                       'packs/actionbar/data/smithed.actionbar/functions/impl/*',
                       'packs/actionbar/data/smithed.actionbar/functions/impl/technical/*',
                       'packs/actionbar/data/smithed.actionbar/functions/impl/vanilla/bed/*',
                       'packs/actionbar/data/smithed.actionbar/functions/impl/vanilla/container/*',
                       'packs/actionbar/data/smithed.actionbar/functions/impl/vanilla/container/check_double_chest_lock/*',
                       'packs/actionbar/data/smithed.actionbar/predicates/impl/*',
                       'packs/actionbar/data/smithed.actionbar/tags/blocks/impl/*',
                       'packs/actionbar/data/smithed.actionbar/tags/functions/event/player/*',
                       'packs/crafter-addon/*',
                       'packs/crafter-addon/data/smithed.crafter/tags/functions/event/*',
                       'packs/crafter-addon/data/smithed.crafter_addon/functions/impl/recipes/shaped/*',
                       'packs/crafter-addon/data/smithed.crafter_addon/functions/impl/recipes/shapeless/*',
                       'packs/crafter-addon/data/smithed.crafter_addon/functions/impl/tags/*',
                       'packs/crafter-addon/data/smithed.crafter_addon/predicates/recipes/*',
                       'packs/crafter/*',
                       'packs/crafter/assets/minecraft/models/item/*',
                       'packs/crafter/assets/smithed.crafter/font/*',
                       'packs/crafter/assets/smithed.crafter/lang/*',
                       'packs/crafter/assets/smithed.crafter/models/item/*',
                       'packs/crafter/assets/smithed.crafter/textures/block/*',
                       'packs/crafter/assets/smithed.crafter/textures/gui/*',
                       'packs/crafter/data/smithed.crafter/advancements/technical/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/break/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/crafting/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/crafting/input/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/crafting/manage_invalids/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/crafting/output/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/crafting/output/clear_input/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/crafting/output/clear_input/advanced/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/crafting/output/clear_input/delete_tool/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/crafting/output/cursor_check/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/crafting/output/shift_click/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/crafting/shapeless_recipes/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/crafting/shapeless_recipes/checks/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/block/table/interact/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/entity/player/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/recipes/*',
                       'packs/crafter/data/smithed.crafter/functions/impl/technical/*',
                       'packs/crafter/data/smithed.crafter/functions/zint/technical/*',
                       'packs/crafter/data/smithed.crafter/item_modifiers/impl/*',
                       'packs/crafter/data/smithed.crafter/loot_tables/blocks/*',
                       'packs/crafter/data/smithed.crafter/predicates/block/table/*',
                       'packs/crafter/data/smithed.crafter/predicates/block/table/special_clear/*',
                       'packs/crafter/data/smithed.crafter/recipes/*',
                       'packs/crafter/data/smithed.crafter/tags/functions/event/*',
                       'packs/crafter/data/smithed.custom_block/tags/functions/event/*',
                       'packs/custom-block/*',
                       'packs/custom-block/data/smithed.custom_block/advancements/impl/technical/*',
                       'packs/custom-block/data/smithed.custom_block/functions/impl/*',
                       'packs/custom-block/data/smithed.custom_block/functions/impl/place/*',
                       'packs/custom-block/data/smithed.custom_block/functions/impl/technical/*',
                       'packs/custom-block/data/smithed.custom_block/tags/blocks/*',
                       'packs/damage/*',
                       'packs/damage/data/smithed.damage/advancements/impl/player/*',
                       'packs/damage/data/smithed.damage/functions/impl/entity/*',
                       'packs/damage/data/smithed.damage/functions/impl/entity/apply/*',
                       'packs/damage/data/smithed.damage/functions/impl/entity/armor/*',
                       'packs/damage/data/smithed.damage/functions/impl/entity/attributes/*',
                       'packs/damage/data/smithed.damage/functions/impl/entity/health/*',
                       'packs/damage/data/smithed.damage/functions/impl/player/*',
                       'packs/damage/data/smithed.damage/functions/impl/technical/*',
                       'packs/damage/data/smithed.damage/tags/entity_types/*',
                       'packs/damage/data/smithed.damage/tags/functions/event/entity/*',
                       'packs/damage/data/smithed.damage/tags/functions/event/player/*',
                       'packs/enchanter/*',
                       'packs/enchanter/assets/smithed.enchanter/font/*',
                       'packs/enchanter/assets/smithed.enchanter/lang/*',
                       'packs/enchanter/assets/smithed.enchanter/textures/gui/*',
                       'packs/enchanter/data/smithed.enchanter/advancements/impl/*',
                       'packs/enchanter/data/smithed.enchanter/functions/impl/*',
                       'packs/enchanter/data/smithed.enchanter/functions/impl/block/enchanter/*',
                       'packs/enchanter/data/smithed.enchanter/functions/impl/technical/*',
                       'packs/item/*',
                       'packs/item/data/smithed.item/advancements/impl/technical/*',
                       'packs/item/data/smithed.item/functions/impl/durability/*',
                       'packs/item/data/smithed.item/functions/impl/durability/calc_mending/*',
                       'packs/item/data/smithed.item/functions/impl/durability/damage/*',
                       'packs/item/data/smithed.item/functions/impl/durability/damage/force/*',
                       'packs/item/data/smithed.item/functions/impl/durability/process/*',
                       'packs/item/data/smithed.item/functions/impl/lore/*',
                       'packs/item/data/smithed.item/functions/impl/technical/*',
                       'packs/item/data/smithed.item/item_modifiers/*',
                       'packs/item/data/smithed.item/predicates/chance/*',
                       'packs/item/data/smithed.item/tags/functions/event/*',
                       'packs/prevent-aggression/*',
                       'packs/prevent-aggression/data/smithed.prevent_aggression/functions/impl/technical/*',
                       'packs/prevent-aggression/data/smithed.prevent_aggression/tags/entity_types/*']}

install_requires = \
['beet>=0.108.5',
 'bolt-expressions>=0.17.0,<0.18.0',
 'bolt>=0.49.0,<0.50.0',
 'mecha>=0.95.0,<0.96.0',
 'pydantic>=2.5.2,<3.0.0',
 'rich>=13.9.2,<14.0.0']

setup_kwargs = {
    'name': 'smithed-libraries',
    'version': '0.11.0',
    'description': 'All of the Smithed Libraries',
    'long_description': '# Libraries\n\n[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)\n[![Discord](https://img.shields.io/discord/511303648119226382?color=%236d82cc&label=Discord&logo=discord&logoColor=white)](https://discord.gg/gkp6UqEUph)\n\n> Collection of Libraries for the Smithed Ecosystem\n\n## Downloading\n\nYou can download it from [Stable](https://smithed.dev/libraries) | [Nightly](https://nightly.link/Smithed-MC/Libraries/workflows/nightly-build/main/packs.zip)<br/>\nor<br/>\nYou can build it from source using the [beet](https://github.com/mcbeet/beet) via the [Contributing](CONTRIBUTING.md) instructions.\n',
    'author': 'Smithed Council',
    'author_email': 'team@smithed.dev',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
